0.9.9 API documentation: packing.hpp File Reference

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

Functions
gtc/packing.hpp File Reference

GLM_GTC_packing More...

Go to the source code of this file.

## Functions
GLM_FUNC_DECL uint32 | packF2x11_1x10 (vec3 const &v)
| First, converts the first two components of the normalized floating-point value v into 11-bit signless floating-point values. More...
GLM_FUNC_DECL uint32 | packF3x9_E1x5 (vec3 const &v)
| First, converts the first two components of the normalized floating-point value v into 11-bit signless floating-point values. More...
template<length_t L, qualifier Q>
GLM_FUNC_DECL vec< L, uint16, Q > | packHalf (vec< L, float, Q > const &v)
| Returns an unsigned integer vector obtained by converting the components of a floating-point vector to the 16-bit floating-point representation found in the OpenGL Specification. More...
GLM_FUNC_DECL uint16 | packHalf1x16 (float v)
| Returns an unsigned integer obtained by converting the components of a floating-point scalar to the 16-bit floating-point representation found in the OpenGL Specification, and then packing this 16-bit value into a 16-bit unsigned integer. More...
GLM_FUNC_DECL uint64 | packHalf4x16 (vec4 const &v)
| Returns an unsigned integer obtained by converting the components of a four-component floating-point vector to the 16-bit floating-point representation found in the OpenGL Specification, and then packing these four 16-bit values into a 64-bit unsigned integer. More...
GLM_FUNC_DECL uint32 | packI3x10_1x2 (ivec4 const &v)
| Returns an unsigned integer obtained by converting the components of a four-component signed integer vector to the 10-10-10-2-bit signed integer representation found in the OpenGL Specification, and then packing these four values into a 32-bit unsigned integer. More...
GLM_FUNC_DECL int | packInt2x16 (i16vec2 const &v)
| Convert each component from an integer vector into a packed integer. More...
GLM_FUNC_DECL int64 | packInt2x32 (i32vec2 const &v)
| Convert each component from an integer vector into a packed integer. More...
GLM_FUNC_DECL int16 | packInt2x8 (i8vec2 const &v)
| Convert each component from an integer vector into a packed integer. More...
GLM_FUNC_DECL int64 | packInt4x16 (i16vec4 const &v)
| Convert each component from an integer vector into a packed integer. More...
GLM_FUNC_DECL int32 | packInt4x8 (i8vec4 const &v)
| Convert each component from an integer vector into a packed integer. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< 4, T, Q > | packRGBM (vec< 3, T, Q > const &rgb)
| Returns an unsigned integer vector obtained by converting the components of a floating-point vector to the 16-bit floating-point representation found in the OpenGL Specification. More...
template<typename intType , length_t L, typename floatType , qualifier Q>
GLM_FUNC_DECL vec< L, intType, Q > | packSnorm (vec< L, floatType, Q > const &v)
| Convert each component of the normalized floating-point vector into signed integer values. More...
GLM_FUNC_DECL uint16 | packSnorm1x16 (float v)
| First, converts the normalized floating-point value v into 16-bit integer value. More...
GLM_FUNC_DECL uint8 | packSnorm1x8 (float s)
| First, converts the normalized floating-point value v into 8-bit integer value. More...
GLM_FUNC_DECL uint16 | packSnorm2x8 (vec2 const &v)
| First, converts each component of the normalized floating-point value v into 8-bit integer values. More...
GLM_FUNC_DECL uint32 | packSnorm3x10_1x2 (vec4 const &v)
| First, converts the first three components of the normalized floating-point value v into 10-bit signed integer values. More...
GLM_FUNC_DECL uint64 | packSnorm4x16 (vec4 const &v)
| First, converts each component of the normalized floating-point value v into 16-bit integer values. More...
GLM_FUNC_DECL uint32 | packU3x10_1x2 (uvec4 const &v)
| Returns an unsigned integer obtained by converting the components of a four-component unsigned integer vector to the 10-10-10-2-bit unsigned integer representation found in the OpenGL Specification, and then packing these four values into a 32-bit unsigned integer. More...
GLM_FUNC_DECL uint | packUint2x16 (u16vec2 const &v)
| Convert each component from an integer vector into a packed unsigned integer. More...
GLM_FUNC_DECL uint64 | packUint2x32 (u32vec2 const &v)
| Convert each component from an integer vector into a packed unsigned integer. More...
GLM_FUNC_DECL uint16 | packUint2x8 (u8vec2 const &v)
| Convert each component from an integer vector into a packed unsigned integer. More...
GLM_FUNC_DECL uint64 | packUint4x16 (u16vec4 const &v)
| Convert each component from an integer vector into a packed unsigned integer. More...
GLM_FUNC_DECL uint32 | packUint4x8 (u8vec4 const &v)
| Convert each component from an integer vector into a packed unsigned integer. More...
template<typename uintType , length_t L, typename floatType , qualifier Q>
GLM_FUNC_DECL vec< L, uintType, Q > | packUnorm (vec< L, floatType, Q > const &v)
| Convert each component of the normalized floating-point vector into unsigned integer values. More...
GLM_FUNC_DECL uint16 | packUnorm1x16 (float v)
| First, converts the normalized floating-point value v into a 16-bit integer value. More...
GLM_FUNC_DECL uint16 | packUnorm1x5_1x6_1x5 (vec3 const &v)
| Convert each component of the normalized floating-point vector into unsigned integer values. More...
GLM_FUNC_DECL uint8 | packUnorm1x8 (float v)
| First, converts the normalized floating-point value v into a 8-bit integer value. More...
GLM_FUNC_DECL uint8 | packUnorm2x3_1x2 (vec3 const &v)
| Convert each component of the normalized floating-point vector into unsigned integer values. More...
GLM_FUNC_DECL uint8 | packUnorm2x4 (vec2 const &v)
| Convert each component of the normalized floating-point vector into unsigned integer values. More...
GLM_FUNC_DECL uint16 | packUnorm2x8 (vec2 const &v)
| First, converts each component of the normalized floating-point value v into 8-bit integer values. More...
GLM_FUNC_DECL uint32 | packUnorm3x10_1x2 (vec4 const &v)
| First, converts the first three components of the normalized floating-point value v into 10-bit unsigned integer values. More...
GLM_FUNC_DECL uint16 | packUnorm3x5_1x1 (vec4 const &v)
| Convert each component of the normalized floating-point vector into unsigned integer values. More...
GLM_FUNC_DECL uint64 | packUnorm4x16 (vec4 const &v)
| First, converts each component of the normalized floating-point value v into 16-bit integer values. More...
GLM_FUNC_DECL uint16 | packUnorm4x4 (vec4 const &v)
| Convert each component of the normalized floating-point vector into unsigned integer values. More...
GLM_FUNC_DECL vec3 | unpackF2x11_1x10 (uint32 p)
| First, unpacks a single 32-bit unsigned integer p into two 11-bit signless floating-point values and one 10-bit signless floating-point value . More...
GLM_FUNC_DECL vec3 | unpackF3x9_E1x5 (uint32 p)
| First, unpacks a single 32-bit unsigned integer p into two 11-bit signless floating-point values and one 10-bit signless floating-point value . More...
template<length_t L, qualifier Q>
GLM_FUNC_DECL vec< L, float, Q > | unpackHalf (vec< L, uint16, Q > const &p)
| Returns a floating-point vector with components obtained by reinterpreting an integer vector as 16-bit floating-point numbers and converting them to 32-bit floating-point values. More...
GLM_FUNC_DECL float | unpackHalf1x16 (uint16 v)
| Returns a floating-point scalar with components obtained by unpacking a 16-bit unsigned integer into a 16-bit value, interpreted as a 16-bit floating-point number according to the OpenGL Specification, and converting it to 32-bit floating-point values. More...
GLM_FUNC_DECL vec4 | unpackHalf4x16 (uint64 p)
| Returns a four-component floating-point vector with components obtained by unpacking a 64-bit unsigned integer into four 16-bit values, interpreting those values as 16-bit floating-point numbers according to the OpenGL Specification, and converting them to 32-bit floating-point values. More...
GLM_FUNC_DECL ivec4 | unpackI3x10_1x2 (uint32 p)
| Unpacks a single 32-bit unsigned integer p into three 10-bit and one 2-bit signed integers. More...
GLM_FUNC_DECL i16vec2 | unpackInt2x16 (int p)
| Convert a packed integer into an integer vector. More...
GLM_FUNC_DECL i32vec2 | unpackInt2x32 (int64 p)
| Convert a packed integer into an integer vector. More...
GLM_FUNC_DECL i8vec2 | unpackInt2x8 (int16 p)
| Convert a packed integer into an integer vector. More...
GLM_FUNC_DECL i16vec4 | unpackInt4x16 (int64 p)
| Convert a packed integer into an integer vector. More...
GLM_FUNC_DECL i8vec4 | unpackInt4x8 (int32 p)
| Convert a packed integer into an integer vector. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< 3, T, Q > | unpackRGBM (vec< 4, T, Q > const &rgbm)
| Returns a floating-point vector with components obtained by reinterpreting an integer vector as 16-bit floating-point numbers and converting them to 32-bit floating-point values. More...
template<typename floatType , length_t L, typename intType , qualifier Q>
GLM_FUNC_DECL vec< L, floatType, Q > | unpackSnorm (vec< L, intType, Q > const &v)
| Convert a packed integer to a normalized floating-point vector. More...
GLM_FUNC_DECL float | unpackSnorm1x16 (uint16 p)
| First, unpacks a single 16-bit unsigned integer p into a single 16-bit signed integers. More...
GLM_FUNC_DECL float | unpackSnorm1x8 (uint8 p)
| First, unpacks a single 8-bit unsigned integer p into a single 8-bit signed integers. More...
GLM_FUNC_DECL vec2 | unpackSnorm2x8 (uint16 p)
| First, unpacks a single 16-bit unsigned integer p into a pair of 8-bit signed integers. More...
GLM_FUNC_DECL vec4 | unpackSnorm3x10_1x2 (uint32 p)
| First, unpacks a single 32-bit unsigned integer p into four 16-bit signed integers. More...
GLM_FUNC_DECL vec4 | unpackSnorm4x16 (uint64 p)
| First, unpacks a single 64-bit unsigned integer p into four 16-bit signed integers. More...
GLM_FUNC_DECL uvec4 | unpackU3x10_1x2 (uint32 p)
| Unpacks a single 32-bit unsigned integer p into three 10-bit and one 2-bit unsigned integers. More...
GLM_FUNC_DECL u16vec2 | unpackUint2x16 (uint p)
| Convert a packed integer into an integer vector. More...
GLM_FUNC_DECL u32vec2 | unpackUint2x32 (uint64 p)
| Convert a packed integer into an integer vector. More...
GLM_FUNC_DECL u8vec2 | unpackUint2x8 (uint16 p)
| Convert a packed integer into an integer vector. More...
GLM_FUNC_DECL u16vec4 | unpackUint4x16 (uint64 p)
| Convert a packed integer into an integer vector. More...
GLM_FUNC_DECL u8vec4 | unpackUint4x8 (uint32 p)
| Convert a packed integer into an integer vector. More...
template<typename floatType , length_t L, typename uintType , qualifier Q>
GLM_FUNC_DECL vec< L, floatType, Q > | unpackUnorm (vec< L, uintType, Q > const &v)
| Convert a packed integer to a normalized floating-point vector. More...
GLM_FUNC_DECL float | unpackUnorm1x16 (uint16 p)
| First, unpacks a single 16-bit unsigned integer p into a of 16-bit unsigned integers. More...
GLM_FUNC_DECL vec3 | unpackUnorm1x5_1x6_1x5 (uint16 p)
| Convert a packed integer to a normalized floating-point vector. More...
GLM_FUNC_DECL float | unpackUnorm1x8 (uint8 p)
| Convert a single 8-bit integer to a normalized floating-point value. More...
GLM_FUNC_DECL vec3 | unpackUnorm2x3_1x2 (uint8 p)
| Convert a packed integer to a normalized floating-point vector. More...
GLM_FUNC_DECL vec2 | unpackUnorm2x4 (uint8 p)
| Convert a packed integer to a normalized floating-point vector. More...
GLM_FUNC_DECL vec2 | unpackUnorm2x8 (uint16 p)
| First, unpacks a single 16-bit unsigned integer p into a pair of 8-bit unsigned integers. More...
GLM_FUNC_DECL vec4 | unpackUnorm3x10_1x2 (uint32 p)
| First, unpacks a single 32-bit unsigned integer p into four 16-bit signed integers. More...
GLM_FUNC_DECL vec4 | unpackUnorm3x5_1x1 (uint16 p)
| Convert a packed integer to a normalized floating-point vector. More...
GLM_FUNC_DECL vec4 | unpackUnorm4x16 (uint64 p)
| First, unpacks a single 64-bit unsigned integer p into four 16-bit unsigned integers. More...
GLM_FUNC_DECL vec4 | unpackUnorm4x4 (uint16 p)
| Convert a packed integer to a normalized floating-point vector. More...

## Detailed Description

GLM_GTC_packing

See also
  Core features (dependence)

Definition in file gtc/packing.hpp.